@@ -12,7 +12,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::NextVersion;
 # ABSTRACT: Provide a version number by bumping the last git release tag
 
-our $VERSION = '2.044';
+our $VERSION = '2.049';
 
 use Dist::Zilla 4 ();
 use version 0.80 ();
@@ -21,8 +21,8 @@ use Moose;
 use namespace::autoclean 0.09;
 use Path::Tiny;
 use Try::Tiny;
-use Moose::Util::TypeConstraints;
-use MooseX::Types::Moose qw(Str RegexpRef Bool ArrayRef);
+use Types::Standard qw(Str RegexpRef Bool ArrayRef);
+use Type::Utils qw(coerce from as via subtype);
 
 use constant _cache_fn => '.gitnxtver_cache';
 
@@ -52,7 +52,7 @@ sub _versions_from_tags {
 
   # WARNING: The quotes in "$1" are necessary, because version doesn't
   # call get magic properly.
-  return [ sort map { /$regexp/ ? try { version->parse("$1") } : () } @$tags ];
+  return [ sort map /$regexp/ ? try { version->parse("$1") } : (), @$tags ];
 } # end _versions_from_tags
 
 has _all_versions => (
@@ -88,7 +88,7 @@ sub _last_version {
 
   if ($by_branch) {
     my $head;
-    my $cachefile = $self->zilla->root->child(_cache_fn);
+    my $cachefile = path($self->zilla->root)->child(_cache_fn);
     if (-f $cachefile) {
       ($head) = $git->rev_parse('HEAD');
       return $1 if $cachefile->slurp =~ /^\Q$head\E (.+)/;
@@ -133,7 +133,7 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        (map { $_ => $self->$_ } qw(version_regexp first_version)),
+        (map +($_ => $self->$_), qw(version_regexp first_version)),
         version_by_branch => $self->version_by_branch ? 1 : 0,
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
@@ -148,7 +148,7 @@ sub before_release {
   my $version = version->parse( $self->zilla->version );
 
   $self->log_fatal("version $version has already been tagged")
-      if grep { $_ == $version } @{ $self->_all_versions };
+      if grep +($_ == $version), @{ $self->_all_versions };
 }
 
 sub after_release {
@@ -208,7 +208,7 @@ Dist::Zilla::Plugin::Git::NextVersion - Provide a version number by bumping the
 
 =head1 VERSION
 
-version 2.044
+version 2.049
 
 =head1 SYNOPSIS
 
@@ -291,8 +291,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
